@@ -13,9 +13,6 @@
 
 module Diagrams.Transform.Matrix where
 
-#if __GLASGOW_HASKELL__ < 710
-import           Control.Applicative
-#endif
 import           Control.Arrow           ((&&&))
 import           Control.Lens
 import           Data.Distributive
